@@ -43,6 +43,7 @@ typedef struct GetInfoState GetInfoState;
 typedef struct NewFilesState NewFilesState;
 typedef struct MimeListState MimeListState;
 typedef struct ThumbnailState ThumbnailState;
+typedef struct MountState MountState;
 
 struct NautilusDirectoryDetails
 {
@@ -105,6 +106,8 @@ struct NautilusDirectoryDetails
 	guint extension_info_idle;
 
 	ThumbnailState *thumbnail_state;
+
+	MountState *mount_state;
 	
 	TopLeftTextReadState *top_left_read_state;
 
@@ -128,6 +131,7 @@ typedef struct {
 	gboolean large_top_left_text;
 	gboolean extension_info;
 	gboolean thumbnail;
+	gboolean mount;
 } Request;
 
 NautilusDirectory *nautilus_directory_get_existing                    (GFile                     *location);
