@@ -29,15 +29,15 @@
 
 #include <gdk/gdkdnd.h>
 #include <gtk/gtkwidget.h>
-#include <libgnomevfs/gnome-vfs-types.h>
+#include <gio/gio.h>
 
 typedef void (* NautilusCopyCallback)      (GHashTable *debuting_uris,
 					    gpointer    callback_data);
-typedef void (* NautilusNewFolderCallback) (const char *new_folder_uri,
+typedef void (* NautilusCreateCallback)    (GFile      *new_file,
 					    gpointer    callback_data);
-typedef void (* NautilusNewFileCallback)   (const char *new_file_uri,
+typedef void (* NautilusOpCallback)        (gpointer    callback_data);
+typedef void (* NautilusDeleteCallback)    (GHashTable *debuting_uris,
 					    gpointer    callback_data);
-typedef void (* NautilusSetPermissionsCallback) (gpointer    callback_data);
 
 /* FIXME: int copy_action should be an enum */
 
@@ -52,31 +52,71 @@ void nautilus_file_operations_empty_trash (GtkWidget                 *parent_vie
 void nautilus_file_operations_new_folder  (GtkWidget                 *parent_view,
 					   GdkPoint                  *target_point,
 					   const char                *parent_dir_uri,
-					   NautilusNewFolderCallback  done_callback,
+					   NautilusCreateCallback     done_callback,
 					   gpointer                   done_callback_data);
 void nautilus_file_operations_new_file    (GtkWidget                 *parent_view,
 					   GdkPoint                  *target_point,
 					   const char                *parent_dir,
+					   const char                *target_filename,
 					   const char                *initial_contents,
-					   NautilusNewFileCallback    done_callback,
+					   NautilusCreateCallback     done_callback,
 					   gpointer                   data);
 void nautilus_file_operations_new_file_from_template (GtkWidget               *parent_view,
 					   	      GdkPoint                *target_point,
 						      const char              *parent_dir,
 						      const char              *target_filename,
 						      const char              *template_uri,
-						      NautilusNewFileCallback  done_callback,
+						      NautilusCreateCallback   done_callback,
 						      gpointer                 data);
 
-void nautilus_file_operations_delete      (const GList               *item_uris,
-					   GtkWidget                 *parent_view);
+void nautilus_file_operations_delete          (GList                  *files,
+					       GtkWindow              *parent_window,
+					       NautilusDeleteCallback  done_callback,
+					       gpointer                done_callback_data);
+void nautilus_file_operations_trash_or_delete (GList                  *files,
+					       GtkWindow              *parent_window,
+					       NautilusDeleteCallback  done_callback,
+					       gpointer                done_callback_data);
 
 void nautilus_file_set_permissions_recursive (const char                     *directory,
-					      GnomeVFSFilePermissions         file_permissions,
-					      GnomeVFSFilePermissions         file_mask,
-					      GnomeVFSFilePermissions         folder_permissions,
-					      GnomeVFSFilePermissions         folder_mask,
-					      NautilusSetPermissionsCallback  callback,
+					      guint32                         file_permissions,
+					      guint32                         file_mask,
+					      guint32                         folder_permissions,
+					      guint32                         folder_mask,
+					      NautilusOpCallback              callback,
 					      gpointer                        callback_data);
 
+void nautilus_file_operations_unmount_mount (GtkWindow                      *parent_window,
+					     GMount                         *mount,
+					     gboolean                        eject,
+					     gboolean                        check_trash);
+void nautilus_file_operations_mount_volume  (GtkWindow                      *parent_window,
+					     GVolume                        *volume);
+								
+
+void nautilus_file_operations_copy      (GList                *files,
+					 GArray               *relative_item_points,
+					 GFile                *target_dir,
+					 GtkWindow            *parent_window,
+					 NautilusCopyCallback  done_callback,
+					 gpointer              done_callback_data);
+void nautilus_file_operations_move      (GList                *files,
+					 GArray               *relative_item_points,
+					 GFile                *target_dir,
+					 GtkWindow            *parent_window,
+					 NautilusCopyCallback  done_callback,
+					 gpointer              done_callback_data);
+void nautilus_file_operations_duplicate (GList                *files,
+					 GArray               *relative_item_points,
+					 GtkWindow            *parent_window,
+					 NautilusCopyCallback  done_callback,
+					 gpointer              done_callback_data);
+void nautilus_file_operations_link      (GList                *files,
+					 GArray               *relative_item_points,
+					 GFile                *target_dir,
+					 GtkWindow            *parent_window,
+					 NautilusCopyCallback  done_callback,
+					 gpointer              done_callback_data);
+
+
 #endif /* NAUTILUS_FILE_OPERATIONS_H */
