@@ -105,6 +105,7 @@ struct NautilusFileDetails
 	
 	char *thumbnail_path;
 	GdkPixbuf *thumbnail;
+	time_t thumbnail_mtime;
 	int thumbnail_size; /* 0 means original unframed thumbnail */
 	
 	GList *mime_list; /* If this is a directory, the list of MIME types in it. */
@@ -136,6 +137,9 @@ struct NautilusFileDetails
 	GHashTable *extension_attributes;
 	GHashTable *pending_extension_attributes;
 
+	/* Mount for mountpoint or the references GMount for a "mountable" */
+	GMount *mount;
+	
 	/* boolean fields: bitfield to save space, since there can be
            many NautilusFile objects. */
 
@@ -165,6 +169,8 @@ struct NautilusFileDetails
 	eel_boolean_bit mime_list_failed              : 1;
 	eel_boolean_bit mime_list_is_up_to_date       : 1;
 
+	eel_boolean_bit mount_is_up_to_date           : 1;
+	
 	eel_boolean_bit got_top_left_text             : 1;
 	eel_boolean_bit got_large_top_left_text       : 1;
 	eel_boolean_bit top_left_text_is_up_to_date   : 1;
