@@ -39,6 +39,8 @@
 #include <eel/eel-preferences.h>
 #include <eel/eel-stock-dialogs.h>
 
+#include <libnautilus-private/nautilus-icon-names.h>
+
 #include "nautilus-window.h"
 #include "nautilus-connect-server-dialog.h"
 
@@ -108,6 +110,8 @@ main (int argc, char *argv[])
 	textdomain (GETTEXT_PACKAGE);
 
 	args = NULL;
+	/* Translators: This is the --help description gor the connect to server app,
+	   the initial newlines are between the command line arg and the description */
 	context = g_option_context_new (N_("\n\nAdd connect to server mount"));
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 
@@ -122,7 +126,7 @@ main (int argc, char *argv[])
 
 	eel_preferences_init ("/apps/nautilus");
 
-	gtk_window_set_default_icon_name ("gnome-fs-directory");
+	gtk_window_set_default_icon_name (NAUTILUS_ICON_FOLDER);
 
 
 	/* command line arguments, null terminated array */
