@@ -28,13 +28,8 @@
 
 #include <string.h>
 #include <time.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtksizegroup.h>
+#include <gtk/gtk.h>
+#include <gio/gio.h>
 
 #include <libgnome/gnome-help.h>
 #include <glib/gi18n.h>
@@ -50,6 +45,8 @@
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-module.h>
 
+#include <libnautilus-private/nautilus-autorun.h>
+
 /* string enum preferences */
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_DEFAULT_VIEW_WIDGET "default_view_combobox"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_ICON_VIEW_ZOOM_WIDGET "icon_view_zoom_combobox"
@@ -72,6 +69,8 @@
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_OPEN_NEW_WINDOW_WIDGET "new_window_checkbutton"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_SHOW_HIDDEN_WIDGET "hidden_files_checkbutton"
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_TREE_VIEW_FOLDERS_WIDGET "treeview_folders_checkbutton"
+#define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_MEDIA_AUTOMOUNT_OPEN "media_automount_open_checkbutton"
+#define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_MEDIA_AUTORUN_NEVER "media_autorun_never_checkbutton"
 
 /* int enums */
 #define NAUTILUS_FILE_MANAGEMENT_PROPERTIES_THUMBNAIL_LIMIT_WIDGET "preview_image_size_combobox"
@@ -246,8 +245,6 @@ nautilus_file_management_properties_dialog_response_cb (GtkDialog *parent,
 		eel_gconf_monitor_remove ("/apps/nautilus/list_view");
 		eel_gconf_monitor_remove ("/apps/nautilus/preferences");
 		eel_gconf_monitor_remove ("/desktop/gnome/file_views");
-
-		g_object_unref (xml_dialog);
 	}
 }
 
@@ -513,6 +510,147 @@ nautilus_file_management_properties_dialog_setup_list_column_page (GladeXML *xml
 	gtk_box_pack_start (GTK_BOX (box), chooser, TRUE, TRUE, 0);
 }
 
+static void
+nautilus_file_management_properties_dialog_update_media_sensitivity (GladeXML *xml_dialog)
+{
+	gtk_widget_set_sensitive (glade_xml_get_widget (xml_dialog, "media_handling_vbox"), 
+				  ! eel_preferences_get_boolean (NAUTILUS_PREFERENCES_MEDIA_AUTORUN_NEVER));
+}
+
+static void 
+other_type_combo_box_changed (GtkComboBox *combo_box, GtkComboBox *action_combo_box)
+{
+	GtkTreeIter iter;
+	GtkTreeModel *model;
+	char *x_content_type;
+
+	x_content_type = NULL;
+
+	if (!gtk_combo_box_get_active_iter (combo_box, &iter)) {
+		goto out;
+	}
+
+	model = gtk_combo_box_get_model (combo_box);
+	if (model == NULL) {
+		goto out;
+	}
+
+	gtk_tree_model_get (model, &iter, 
+			    2, &x_content_type,
+			    -1);
+
+	nautilus_autorun_prepare_combo_box (GTK_WIDGET (action_combo_box),
+					    x_content_type,
+					    TRUE,
+					    TRUE,
+					    NULL, NULL);
+out:
+	g_free (x_content_type);
+}
+
+
+static void
+nautilus_file_management_properties_dialog_setup_media_page (GladeXML *xml_dialog)
+{
+	unsigned int n;
+	GList *l;
+	GList *content_types;
+	GtkWidget *other_type_combo_box;
+	GtkListStore *other_type_list_store;
+	GtkCellRenderer *renderer;
+	GtkTreeIter iter;
+	const char *s[] = {"media_audio_cdda_combobox",   "x-content/audio-cdda",
+			   "media_video_dvd_combobox",    "x-content/video-dvd",
+			   "media_music_player_combobox", "x-content/audio-player",
+			   "media_dcf_combobox",          "x-content/image-dcf",
+			   "media_software_combobox",     "x-content/software",
+			   NULL};
+
+	for (n = 0; s[n*2] != NULL; n++) {
+		nautilus_autorun_prepare_combo_box (glade_xml_get_widget (xml_dialog, s[n*2]), s[n*2 + 1],
+						    TRUE, TRUE, NULL, NULL); 
+	}
+
+	other_type_combo_box = glade_xml_get_widget (xml_dialog, "media_other_type_combobox");
+
+	other_type_list_store = gtk_list_store_new (3, 
+						    GDK_TYPE_PIXBUF, 
+						    G_TYPE_STRING, 
+						    G_TYPE_STRING);
+
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (other_type_list_store),
+					      1, GTK_SORT_ASCENDING);
+
+
+	content_types = g_content_types_get_registered ();
+
+	for (l = content_types; l != NULL; l = l->next) {
+		char *content_type = l->data;
+		char *description;
+		GIcon *icon;
+		NautilusIconInfo *icon_info;
+		GdkPixbuf *pixbuf;
+		int icon_size;
+
+		if (!g_str_has_prefix (content_type, "x-content/"))
+			continue;
+		for (n = 0; s[n*2] != NULL; n++) {
+			if (strcmp (content_type, s[n*2 + 1]) == 0) {
+				goto skip;
+			}
+		}
+
+		icon_size = nautilus_get_icon_size_for_stock_size (GTK_ICON_SIZE_MENU);
+
+		description = g_content_type_get_description (content_type);
+		gtk_list_store_append (other_type_list_store, &iter);
+		icon = g_content_type_get_icon (content_type);
+		if (icon != NULL) {
+			icon_info = nautilus_icon_info_lookup (icon, icon_size);
+			g_object_unref (icon);
+			pixbuf = nautilus_icon_info_get_pixbuf_at_size (icon_info, icon_size);
+			g_object_unref (icon_info);
+		} else {
+			pixbuf = NULL;
+		}
+
+		gtk_list_store_set (other_type_list_store, &iter, 
+				    0, pixbuf, 
+				    1, description, 
+				    2, content_type, 
+				    -1);
+		if (pixbuf != NULL)
+			g_object_unref (pixbuf);
+		g_free (description);
+	skip:
+		;
+	}
+	g_list_foreach (content_types, (GFunc) g_free, NULL);
+	g_list_free (content_types);
+
+	gtk_combo_box_set_model (GTK_COMBO_BOX (other_type_combo_box), GTK_TREE_MODEL (other_type_list_store));
+	
+	renderer = gtk_cell_renderer_pixbuf_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (other_type_combo_box), renderer, FALSE);
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (other_type_combo_box), renderer,
+					"pixbuf", 0,
+					NULL);
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (other_type_combo_box), renderer, TRUE);
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (other_type_combo_box), renderer,
+					"text", 1,
+					NULL);
+
+	g_signal_connect (G_OBJECT (other_type_combo_box),
+			  "changed",
+			  G_CALLBACK (other_type_combo_box_changed),
+			  glade_xml_get_widget (xml_dialog, "media_other_action_combobox"));
+
+	gtk_combo_box_set_active (GTK_COMBO_BOX (other_type_combo_box), 0);
+
+	nautilus_file_management_properties_dialog_update_media_sensitivity (xml_dialog);
+}
+
 static  void
 nautilus_file_management_properties_dialog_setup (GladeXML *xml_dialog, GtkWindow *window)
 {
@@ -553,6 +691,14 @@ nautilus_file_management_properties_dialog_setup (GladeXML *xml_dialog, GtkWindo
 	eel_preferences_glade_connect_bool (xml_dialog,
 					    NAUTILUS_FILE_MANAGEMENT_PROPERTIES_ALWAYS_USE_BROWSER_WIDGET,
 					    NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER);
+
+	eel_preferences_glade_connect_bool (xml_dialog,
+					    NAUTILUS_FILE_MANAGEMENT_PROPERTIES_MEDIA_AUTOMOUNT_OPEN,
+					    NAUTILUS_PREFERENCES_MEDIA_AUTOMOUNT_OPEN);
+	eel_preferences_glade_connect_bool (xml_dialog,
+					    NAUTILUS_FILE_MANAGEMENT_PROPERTIES_MEDIA_AUTORUN_NEVER,
+					    NAUTILUS_PREFERENCES_MEDIA_AUTORUN_NEVER);
+
 	eel_preferences_glade_connect_bool (xml_dialog,
 					    NAUTILUS_FILE_MANAGEMENT_PROPERTIES_TRASH_CONFIRM_WIDGET,
 					    NAUTILUS_PREFERENCES_CONFIRM_TRASH);
@@ -626,12 +772,20 @@ nautilus_file_management_properties_dialog_setup (GladeXML *xml_dialog, GtkWindo
 
 	nautilus_file_management_properties_dialog_setup_icon_caption_page (xml_dialog);
 	nautilus_file_management_properties_dialog_setup_list_column_page (xml_dialog);
+	nautilus_file_management_properties_dialog_setup_media_page (xml_dialog);
+
+	eel_preferences_add_callback (NAUTILUS_PREFERENCES_MEDIA_AUTORUN_NEVER,
+				      (EelPreferencesCallback ) nautilus_file_management_properties_dialog_update_media_sensitivity,
+				      g_object_ref (xml_dialog));
+
 	
 	/* UI callbacks */
 	dialog = glade_xml_get_widget (xml_dialog, "file_management_dialog");
-	g_signal_connect (G_OBJECT (dialog), "response",
-			  G_CALLBACK (nautilus_file_management_properties_dialog_response_cb),
-			  xml_dialog);
+	g_signal_connect_data (G_OBJECT (dialog), "response",
+			       G_CALLBACK (nautilus_file_management_properties_dialog_response_cb),
+			       g_object_ref (xml_dialog),
+			       (GClosureNotify)g_object_unref,
+			       0);
 
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "file-manager");
 
