@@ -68,7 +68,7 @@ struct NautilusWindowDetails
         guint bookmarks_merge_id;
         
         /* Current location. */
-        char *location;
+        GFile *location;
 	char *title;
 	NautilusFile *viewed_file;
         gboolean viewed_file_seen;
@@ -78,10 +78,13 @@ struct NautilusWindowDetails
         /* New location. */
         NautilusLocationChangeType location_change_type;
         guint location_change_distance;
-        char *pending_location;
+        GFile *pending_location;
         char *pending_scroll_to;
         GList *pending_selection;
         NautilusFile *determine_view_file;
+        GCancellable *mount_cancellable;
+        GError *mount_error;
+        gboolean tried_mount;
 
         /* View As choices */
         GtkActionGroup *view_as_action_group; /* owned by ui_manager */
@@ -93,7 +96,7 @@ struct NautilusWindowDetails
         char *extra_viewer;
 
         /* Deferred location change. */
-        char *location_to_change_to_at_idle;
+        GFile *location_to_change_to_at_idle;
         guint location_change_at_idle_id;
 
         NautilusWindowShowHiddenFilesMode show_hidden_files_mode;
@@ -203,11 +206,11 @@ void               nautilus_window_set_viewed_file                       (Nautil
                                                                           NautilusFile      *file);
 void               nautilus_send_history_list_changed                    (void);
 void               nautilus_window_add_current_location_to_history_list  (NautilusWindow    *window);
-void               nautilus_remove_from_history_list_no_notify           (const char        *location);
-gboolean           nautilus_add_to_history_list_no_notify                (const char        *location,
+void               nautilus_remove_from_history_list_no_notify           (GFile             *location);
+gboolean           nautilus_add_to_history_list_no_notify                (GFile             *location,
 									  const char        *name,
 									  gboolean           has_custom_name,
-									  const char        *icon);
+									  GIcon            *icon);
 GList *            nautilus_get_history_list                             (void);
 void               nautilus_window_bookmarks_preference_changed_callback (gpointer           user_data);
 void		   nautilus_window_update_icon				 (NautilusWindow    *window);
@@ -220,6 +223,7 @@ void               nautilus_navigation_window_remove_bookmarks_menu_callback
 
 void               nautilus_navigation_window_remove_bookmarks_menu_items           (NautilusNavigationWindow    *window);
 void               nautilus_navigation_window_update_show_hide_menu_items           (NautilusNavigationWindow     *window);
+void               nautilus_navigation_window_update_spatial_menu_item              (NautilusNavigationWindow     *window);
 void               nautilus_navigation_window_remove_go_menu_callback    (NautilusNavigationWindow    *window);
 void               nautilus_navigation_window_remove_go_menu_items       (NautilusNavigationWindow    *window);
 
