@@ -29,7 +29,7 @@
 #define NAUTILUS_ZOOM_CONTROL_H
 
 #include <gtk/gtkhbox.h>
-#include <libnautilus-private/nautilus-icon-factory.h> /* For NautilusZoomLevel */
+#include <libnautilus-private/nautilus-icon-info.h> /* For NautilusZoomLevel */
 
 #define NAUTILUS_TYPE_ZOOM_CONTROL	      (nautilus_zoom_control_get_type ())
 #define NAUTILUS_ZOOM_CONTROL(obj)	      (GTK_CHECK_CAST ((obj), NAUTILUS_TYPE_ZOOM_CONTROL, NautilusZoomControl))
